summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/rubyclassifiercodedocument.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenerators/rubyclassifiercodedocument.cpp')
-rw-r--r--umbrello/umbrello/codegenerators/rubyclassifiercodedocument.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/umbrello/umbrello/codegenerators/rubyclassifiercodedocument.cpp b/umbrello/umbrello/codegenerators/rubyclassifiercodedocument.cpp
index ada4b0bb..ecd5523b 100644
--- a/umbrello/umbrello/codegenerators/rubyclassifiercodedocument.cpp
+++ b/umbrello/umbrello/codegenerators/rubyclassifiercodedocument.cpp
@@ -86,10 +86,10 @@ TQString RubyClassifierCodeDocument::getPath ( )
path.simplifyWhiteSpace();
// Replace all blanks with underscore
- path.replace(TQRegExp(" "), "_");
+ path.tqreplace(TQRegExp(" "), "_");
- path.replace(TQRegExp("\\."),"/");
- path.replace(TQRegExp("::"), "/");
+ path.tqreplace(TQRegExp("\\."),"/");
+ path.tqreplace(TQRegExp("::"), "/");
path.lower();
@@ -252,7 +252,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode ( TQDomElement & ro
} else
if( name == "codeoperation" ) {
// find the code operation by id
- TQString id = element.attribute("parent_id","-1");
+ TQString id = element.attribute("tqparent_id","-1");
UMLObject * obj = UMLApp::app()->getDocument()->findObjectById(STR2ID(id));
UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
if(op) {
@@ -355,7 +355,7 @@ void RubyClassifierCodeDocument::resetTextBlocks()
}
// This method will cause the class to rebuild its text representation.
// based on the parent classifier object.
// For any situation in which this is called, we are either building the code
// document up, or replacing/regenerating the existing auto-generated parts. As
// such, we will want to insert everything we resonablely will want
@@ -363,7 +363,7 @@ void RubyClassifierCodeDocument::resetTextBlocks()
// comments) to appear or not, as needed.
void RubyClassifierCodeDocument::updateContent( )
{
// Gather info on the various fields and parent objects of this class...
UMLClassifier * c = getParentClassifier();
RubyCodeGenerator * gen = dynamic_cast<RubyCodeGenerator*>(UMLApp::app()->getGenerator());
@@ -371,7 +371,7 @@ void RubyClassifierCodeDocument::updateContent( )
// This depends on whether or not we have attribute/association classes
CodeClassFieldList * cfList = getCodeClassFieldList();
for(CodeClassField * field = cfList->first(); field; field = cfList->next())
- if(field->parentIsAttribute())
+ if(field->tqparentIsAttribute())
field->setWriteOutMethods(gen->getAutoGenerateAttribAccessors());
else
field->setWriteOutMethods(gen->getAutoGenerateAssocAccessors());
@@ -399,7 +399,7 @@ void RubyClassifierCodeDocument::updateContent( )
CodeClassFieldList privAggregationClassFields = getSpecificClassFields ( CodeClassField::Aggregation, Uml::Visibility::Private);
CodeClassFieldList privCompositionClassFields = getSpecificClassFields ( CodeClassField::Composition, Uml::Visibility::Private);
- bool isInterface = parentIsInterface();
+ bool isInterface = tqparentIsInterface();
bool hasOperationMethods = c->getOpList().last() ? true : false;
CodeGenerationPolicy *pol = UMLApp::app()->getCommonPolicy();
TQString endLine = pol->getNewLineEndingChars(); // a shortcut..so we don't have to call this all the time
@@ -435,7 +435,7 @@ void RubyClassifierCodeDocument::updateContent( )
// NOW create document in sections..
// now we want to populate the body of our class
- // our layout is the following general groupings of code blocks:
+ // our tqlayout is the following general groupings of code blocks:
// start ruby classifier document
@@ -355,7 +355,7 @@ void RubyClassifierCodeDocument::resetTextBlocks()
}
// This method will cause the class to rebuild its text representation.
-// based on the parent classifier object.
+// based on the tqparent classifier object.
// For any situation in which this is called, we are either building the code
// document up, or replacing/regenerating the existing auto-generated parts. As
@@ -363,7 +363,7 @@ void RubyClassifierCodeDocument::resetTextBlocks()
void RubyClassifierCodeDocument::updateContent( )
{
- // Gather info on the various fields and parent objects of this class...
+ // Gather info on the various fields and tqparent objects of this class...
UMLClassifier * c = getParentClassifier();
RubyCodeGenerator * gen = dynamic_cast<RubyCodeGenerator*>(UMLApp::app()->getGenerator());